aov_car et al. of class afex_aov containing both the ANOVA fitted via car::Anova and base R's aov.
"anova"(object, es = afex_options("es_aov"), observed = NULL, correction = afex_options("correction_aov"), MSE = TRUE, intercept = FALSE, p.adjust.method = NULL, ...)
"print"(x, ...)
"summary"(object, ...)
"recover.data"(object, ...)
"lsm.basis"(object, trms, xlev, grid, ...)afex_aov as returned from aov_car and related functions.afex_options("es_aov"), which is initially set to "ges" (i.e., reporting generalized eta-squared, see details). Also supported is partial eta-squared ("pes") or "none".es is not "ges"), see details.afex_options("correction_aov"), which is initially set to "GG" corresponding to the Greenhouse-Geisser correction. Possible values are "GG", "HF" (i.e., Hyunh-Feldt correction), and "none" (i.e., no correction).TRUE.FALSE which hides the intercept.character indicating if p-values for individual effects should be adjusted for multiple comparisons (see p.adjust and details).lsm.basis.anovac("anova", "data.frame"). Information such as effect size (es) or df-correction are calculated each time this method is called.summarysummary.Anova.mlm). For other ANOVAs, the anova table is simply returned.printnice (i.e., as strings rounded nicely). Arguments in ... are passed to nice allowing to pass arguments such as es and correction.recover.data and lsm.basislsmeans and related functions from lsmeans directly on afex_aov objects by returning a ref.grid object. Should not be called directly but through the functionality provided by lsmeans.p.adjust.method.
p.adjust.method defaults to the method specified in the call to aov_car in anova_table. If no method was specified and p.adjust.method = NULL p-values are not adjusted.